--[[
LuCI support for dj
Copyright (C) 2010-2011 Thinktube Inc
]]--
module("luci.controller.dj", package.seeall)

function index()
	require("luci.i18n")
	luci.i18n.loadc("dj")
	if not nixio.fs.access("/etc/config/dj") then
		return
	end

	entry({"admin", "dj"}, alias("admin", "dj", "settings"), luci.i18n.translate("dj_menu_title", "DJ"), 91)
	entry({"admin", "dj", "settings"}, cbi("dj/dj"), luci.i18n.translate("dj_setting", "Settings"), 20)
	entry({"admin", "dj", "alert"}, cbi("dj/dj_alert"), luci.i18n.translate("dj_alert", "Alert Settings"), 30)
	entry({"admin", "dj", "key"}, call("dj_key"), luci.i18n.translate("dj_key", "Key Settings"), 40)
	entry({"admin", "dj", "status"}, call("dj_status"), luci.i18n.translate("dj_status", "Status"), 50)
end

function dj_key()
	local gpgdir = "/etc/gnupg"  -- make sure this path is same with directory of openwrt gpg
	local tmpkey = "/tmp/dj_gpg_key.tmp"
	local file
	luci.http.setfilehandler(
		function(meta, chunk, eof)
			if not file then
				file = io.open(tmpkey, "w")
			end
			if file and chunk then
				file:write(chunk)
			end
			if file and eof then
				file:close()
			end
		end
	)

	local function import_key(key)
		local code = os.execute("gpg --homedir " .. gpgdir .. " --import " .. key)
		return (code == 0) and true or false
	end

	local has_upload = luci.http.formvalue("gpg_key")
	local submit = luci.http.formvalue("submit")
	local state = submit and luci.http.formvalue("state")
	local errmes

	if state == "upload" and has_upload then
		if nixio.fs.access(tmpkey) and import_key(tmpkey) then
			state = "success"
		else
			state = "error"
		end
		-- cleanup
		nixio.fs.unlink(tmpkey)
	end

	luci.template.render("dj/dj_key", {
		state=state, errmes=errmes})
end

function dj_status()
	local start = luci.http.formvalue("dj_start")
	local stop = luci.http.formvalue("dj_stop")
	local restart = luci.http.formvalue("dj_restart")

	local function dj_service(action)
		luci.sys.exec("/etc/init.d/dj " .. action)
		luci.sys.exec("sleep 4") -- xxx: to make sure dj process activate...
	end

	if start then
		dj_service("start")
	elseif stop then
		dj_service("stop")
	elseif restart then
		dj_service("restart")
	end
	luci.template.render("dj/dj_status")
end
