--[[
LuCI support for MeshCruzer
Copyright (C) 2010-2011 Thinktube Inc
]]--
module("luci.controller.meshcruzer", package.seeall)

function index()
	require("luci.i18n")
	luci.i18n.loadc("meshcruzer")
	if not nixio.fs.access("/etc/config/meshz") then
		return
	end

	entry({"admin", "meshcruzer"}, alias("admin", "meshcruzer", "settings"), "MeshCruzer", 90)
	entry({"admin", "meshcruzer", "settings"}, cbi("meshcruzer/meshcruzer"), luci.i18n.translate("mz_setting"), 20)
	entry({"admin", "meshcruzer", "status"}, call("action_meshz_status"), luci.i18n.translate("mz_status"), 30)
	entry({"admin", "meshcruzer", "license"}, call("action_license"), luci.i18n.translate("mz_license_auth"), 40)
end

function action_meshz_status()
	local req = luci.http.formvalue("req")

	if req then
		luci.template.render("meshcruzer/meshcruzer", {req=req})
	else
		luci.template.render("meshcruzer/meshcruzer")
	end
end

function action_license()

	local tmpfile = "/tmp/license.tmp"
	local file
	luci.http.setfilehandler(
		function(meta, chunk, eof)
			if not file then
				file = io.open(tmpfile, "w")
			end
			if file and chunk then
				file:write(chunk)
			end
			if file and eof then
				file:close()
			end
		end
	)

	local function filter_license_name(file)
		return string.match(file, "^mc_license.enc")
	end

	local has_upload = luci.http.formvalue("license")
	local submit = luci.http.formvalue("submit")
	local state = submit and luci.http.formvalue("state")
	local path = "/etc/thinktube/mc_license.enc"
	local has_file
	local errmes

	if state == "upload" then
		if has_upload and filter_license_name(has_upload) then
			if nixio.fs.access(path) then
				nixio.fs.move(path, path..".old")
			end
			-- copy and rename license file
			nixio.fs.move(tmpfile, path)
			has_file = nixio.fs.access(path)
			if has_file then
				state = "success"
			else
				state = "error"
			end
		else
			state = "error"
			errmes = luci.i18n.translate("mz_license_wrong_name")
		end
	end

	luci.template.render("meshcruzer/license", {
		state=state, errmes=errmes})
end
